EncryptedParamType

Enum EncryptedParamType 

#[non_exhaustive]
pub enum EncryptedParamType { Decimal { precision: u8, scale: u8, }, Time { scale: u8, }, DateTime2 { scale: u8, }, DateTimeOffset { scale: u8, }, DateTime, Char { length: u16, }, NChar { length: u16, }, Binary { length: u16, }, }
The explicit SQL type for an Always Encrypted parameter whose value cannot convey it (see numeric, time, datetime2, datetimeoffset, datetime). Carries the precision/scale/length the encrypted column requires the declared parameter type to match exactly.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Decimal

decimal(precision, scale).

Fields

precision: u8

Total number of significant digits (1–38).

scale: u8

Number of digits to the right of the decimal point.



Time

time(scale).

Fields

scale: u8

Fractional-second digits (0–7).



DateTime2

datetime2(scale).

Fields

scale: u8

Fractional-second digits (0–7).



DateTimeOffset

datetimeoffset(scale).

Fields

scale: u8

Fractional-second digits (0–7).



DateTime

Legacy datetime (8 bytes; ~3.33 ms resolution).



Char

Fixed-length char(length) (length in bytes; the encrypted column must use a *_BIN2 collation, and the value is encoded in its code page).

Fields

length: u16

Declared length in bytes.



NChar

Fixed-length nchar(length) (length in UTF-16 characters; the encrypted column must use a *_BIN2 collation).

Fields

length: u16

Declared length in characters.



Binary

Fixed-length binary(length) (length in bytes).

Fields

length: u16

Declared length in bytes.