TypeError

Enum TypeError 

#[non_exhaustive]
pub enum TypeError { UnexpectedNull, TypeMismatch { expected: &'static str, actual: String, }, OutOfRange { target_type: &'static str, }, InvalidEncoding(String), InvalidBinary(String), InvalidDateTime(String), InvalidDecimal(String), InvalidUuid(String), Truncation(String), UnsupportedConversion { from: String, to: &'static str, }, UnsupportedType { sql_type: String, reason: String, }, BufferTooSmall { needed: usize, available: usize, }, }
Errors that can occur during type conversion.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedNull

Value is null when non-null was expected.



TypeMismatch

Type mismatch during conversion.

Fields

expected: &'static str

Expected type name.

actual: String

Actual type name.



OutOfRange

Value is out of range for target type.

Fields

target_type: &'static str

Target type name.



InvalidEncoding(String)

Invalid encoding in string data.



InvalidBinary(String)

Invalid binary data.



InvalidDateTime(String)

Invalid date/time value.



InvalidDecimal(String)

Invalid decimal value.



InvalidUuid(String)

Invalid UUID value.



Truncation(String)

Truncation occurred during conversion.



UnsupportedConversion

Unsupported type conversion.

Fields

from: String

Source type.

to: &'static str

Target type.



UnsupportedType

SQL type rejected as unsupported in this context (e.g. deprecated types).

Fields

sql_type: String

The rejected SQL type name.

reason: String

Explanation and suggested alternative.



BufferTooSmall

Buffer too small for value.

Fields

needed: usize

Bytes needed.

available: usize

Bytes available.

Implementations

Source

impl TypeError

pub fn is_transient(&self) -> bool

Check if this error is transient and may succeed on retry.

Type conversion errors are always terminal — they indicate a mismatch between the SQL type and the Rust type, which won’t resolve itself on retry.

pub fn is_terminal(&self) -> bool

Check if this error is terminal and will never succeed on retry.

All type errors are terminal.